cis_config: asciiTable_t Struct Reference

cis_config

Public Attributes | List of all members
asciiTable_t Struct Reference

Structure containing information about an ASCII table. More...

`#include <AsciiTable.h>`

## Public Attributes
asciiFile_t | f
| ASCII file structure.
char | format_str [LINE_SIZE_MAX]
| Format string for rows.
char | column [64]
| Character(s) used to seperate columns.
int | ncols
| Number of columns in the table.
int * | format_typ
| Array of ncols integers specifying column types.
int * | format_siz
| Array of ncols sizes for elements in each column.
int | row_siz
| Size of an entire row in bytes.
int | status
| Negative if format_str has not been set yet.

## Detailed Description

Structure containing information about an ASCII table.

The documentation for this struct was generated from the following file:

- /root/cis_interface/cis_interface/cis_interface/dataio/AsciiTable.h